@@ -21,12 +21,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/coreos/prometheus-operator/pkg/alertmanager"
-	monv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
-	monitoring "github.com/coreos/prometheus-operator/pkg/client/versioned"
-	prometheusoperator "github.com/coreos/prometheus-operator/pkg/prometheus"
-	"github.com/coreos/prometheus-operator/pkg/thanos"
-	thanosoperator "github.com/coreos/prometheus-operator/pkg/thanos"
 	"github.com/imdario/mergo"
 	configv1 "github.com/openshift/api/config/v1"
 	routev1 "github.com/openshift/api/route/v1"
@@ -35,6 +29,12 @@ import (
 	openshiftrouteclientset "github.com/openshift/client-go/route/clientset/versioned"
 	openshiftsecurityclientset "github.com/openshift/client-go/security/clientset/versioned"
 	"github.com/pkg/errors"
+	"github.com/prometheus-operator/prometheus-operator/pkg/alertmanager"
+	monv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
+	monitoring "github.com/prometheus-operator/prometheus-operator/pkg/client/versioned"
+	prometheusoperator "github.com/prometheus-operator/prometheus-operator/pkg/prometheus"
+	"github.com/prometheus-operator/prometheus-operator/pkg/thanos"
+	thanosoperator "github.com/prometheus-operator/prometheus-operator/pkg/thanos"
 	admissionv1 "k8s.io/api/admissionregistration/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
@@ -48,7 +48,7 @@ import (
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/cache"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 	apiregistrationv1 "k8s.io/kube-aggregator/pkg/apis/apiregistration/v1"
 	aggregatorclient "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset"
 )
@@ -569,7 +569,7 @@ func (c *Client) WaitForPrometheus(p *monv1.Prometheus) error {
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving Prometheus object failed")
 		}
-		status, _, err := prometheusoperator.PrometheusStatus(c.kclient.(*kubernetes.Clientset), p)
+		status, _, err := prometheusoperator.PrometheusStatus(context.TODO(), c.kclient.(*kubernetes.Clientset), p)
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving Prometheus status failed")
 		}
@@ -602,7 +602,7 @@ func (c *Client) WaitForAlertmanager(a *monv1.Alertmanager) error {
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving Alertmanager object failed")
 		}
-		status, _, err := alertmanager.AlertmanagerStatus(c.kclient.(*kubernetes.Clientset), a)
+		status, _, err := alertmanager.AlertmanagerStatus(context.TODO(), c.kclient.(*kubernetes.Clientset), a)
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving Alertmanager status failed")
 		}
@@ -635,7 +635,7 @@ func (c *Client) WaitForThanosRuler(t *monv1.ThanosRuler) error {
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving Thanos Ruler object failed")
 		}
-		status, _, err := thanos.ThanosRulerStatus(c.kclient.(*kubernetes.Clientset), tr)
+		status, _, err := thanos.ThanosRulerStatus(context.TODO(), c.kclient.(*kubernetes.Clientset), tr)
 		if err != nil {
 			return false, errors.Wrap(err, "retrieving Thanos Ruler status failed")
 		}
