@@ -21,14 +21,16 @@ import (
 	"strings"
 	"testing"
 
-	monv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	configv1 "github.com/openshift/api/config/v1"
+	monv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+const assetsPath = "../../assets"
+
 func TestHashSecret(t *testing.T) {
 	for _, tt := range []struct {
 		name            string
@@ -104,7 +106,7 @@ func TestHashSecret(t *testing.T) {
 		},
 	} {
 		t.Run(tt.name, func(t *testing.T) {
-			f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", NewDefaultConfig())
+			f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", NewDefaultConfig(), NewAssets(assetsPath))
 			s, err := f.HashSecret(tt.given, tt.data...)
 			if got := err != nil; got != tt.errExpected {
 				t.Errorf("expected error %t, got %t, err %v", tt.errExpected, got, err)
@@ -119,7 +121,7 @@ func TestHashSecret(t *testing.T) {
 }
 
 func TestUnconfiguredManifests(t *testing.T) {
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", NewDefaultConfig())
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", NewDefaultConfig(), NewAssets(assetsPath))
 	_, err := f.AlertmanagerConfig()
 	if err != nil {
 		t.Fatal(err)
@@ -524,6 +526,11 @@ func TestUnconfiguredManifests(t *testing.T) {
 		t.Fatal(err)
 	}
 
+	_, err = f.PrometheusAdapterServiceMonitor()
+	if err != nil {
+		t.Fatal(err)
+	}
+
 	_, err = f.PrometheusAdapterAPIService()
 	if err != nil {
 		t.Fatal(err)
@@ -639,6 +646,11 @@ func TestUnconfiguredManifests(t *testing.T) {
 		t.Fatal(err)
 	}
 
+	_, err = f.ClusterMonitoringEditUserWorkloadConfigRole()
+	if err != nil {
+		t.Fatal(err)
+	}
+
 	_, err = f.ClusterMonitoringOperatorService()
 	if err != nil {
 		t.Fatal(err)
@@ -666,18 +678,13 @@ func TestUnconfiguredManifests(t *testing.T) {
 }
 
 func TestSharingConfig(t *testing.T) {
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", NewDefaultConfig())
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", NewDefaultConfig(), NewAssets(assetsPath))
 	u, err := url.Parse("http://example.com/")
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	cm := f.SharingConfigDeprecated(u, u, u, u)
-	if cm.Namespace != "openshift-monitoring" {
-		t.Fatalf("expecting %q namespace, got %q", "openshift-monitoring", cm.Namespace)
-	}
-
-	cm = f.SharingConfig(u, u, u, u)
+	cm := f.SharingConfig(u, u, u, u)
 	if cm.Namespace == "openshift-monitoring" {
 		t.Fatalf("expecting namespace other than %q", "openshift-monitoring")
 	}
@@ -707,7 +714,7 @@ func TestPrometheusOperatorConfiguration(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 	d, err := f.PrometheusOperatorDeployment([]string{"default", "openshift-monitoring"})
 	if err != nil {
 		t.Fatal(err)
@@ -727,27 +734,19 @@ func TestPrometheusOperatorConfiguration(t *testing.T) {
 		t.Fatalf("Configuring the Prometheus Operator image failed, expected: %v, got %v", expectedPromOpImage, resPromOpImage)
 	}
 
-	configReloaderFound := false
 	prometheusReloaderFound := false
 	namespacesFound := false
 	for i := range d.Spec.Template.Spec.Containers[0].Args {
 		if strings.HasPrefix(d.Spec.Template.Spec.Containers[0].Args[i], PrometheusConfigReloaderFlag+"docker.io/openshift/origin-prometheus-config-reloader:latest") {
 			prometheusReloaderFound = true
 		}
-		if strings.HasPrefix(d.Spec.Template.Spec.Containers[0].Args[i], ConfigReloaderImageFlag+"docker.io/openshift/origin-configmap-reloader:latest") {
-			configReloaderFound = true
-		}
 		if strings.HasPrefix(d.Spec.Template.Spec.Containers[0].Args[i], PrometheusOperatorNamespaceFlag+"default,openshift-monitoring") {
 			namespacesFound = true
 		}
 	}
 
-	if !configReloaderFound {
-		t.Fatal("Configuring the Config reloader image failed")
-	}
-
 	if !prometheusReloaderFound {
-		t.Fatal("Configuring the Prometheus Reloader image failed")
+		t.Fatal("Configuring the Prometheus Config reloader image failed")
 	}
 
 	if !namespacesFound {
@@ -784,8 +783,8 @@ func TestPrometheusK8sRemoteWrite(t *testing.T) {
 					t.Fatal(err)
 				}
 
-				c.TelemeterClientConfig.ClusterID = "123"
-				c.TelemeterClientConfig.Token = "secret"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.ClusterID = "123"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.Token = "secret"
 
 				return c
 			},
@@ -801,9 +800,9 @@ func TestPrometheusK8sRemoteWrite(t *testing.T) {
 					t.Fatal(err)
 				}
 
-				c.TelemeterClientConfig.ClusterID = "123"
-				c.TelemeterClientConfig.Token = "secret"
-				c.PrometheusK8sConfig.RemoteWrite = []monv1.RemoteWriteSpec{{URL: "http://custom"}}
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.ClusterID = "123"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.Token = "secret"
+				c.ClusterMonitoringConfiguration.PrometheusK8sConfig.RemoteWrite = []monv1.RemoteWriteSpec{{URL: "http://custom"}}
 
 				return c
 			},
@@ -822,8 +821,8 @@ func TestPrometheusK8sRemoteWrite(t *testing.T) {
 				}
 
 				c.SetRemoteWrite(true)
-				c.TelemeterClientConfig.ClusterID = "123"
-				c.TelemeterClientConfig.Token = "secret"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.ClusterID = "123"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.Token = "secret"
 
 				return c
 			},
@@ -842,9 +841,9 @@ func TestPrometheusK8sRemoteWrite(t *testing.T) {
 				}
 
 				c.SetRemoteWrite(true)
-				c.TelemeterClientConfig.ClusterID = "123"
-				c.TelemeterClientConfig.Token = "secret"
-				c.PrometheusK8sConfig.RemoteWrite = []monv1.RemoteWriteSpec{{URL: "http://custom"}}
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.ClusterID = "123"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.Token = "secret"
+				c.ClusterMonitoringConfiguration.PrometheusK8sConfig.RemoteWrite = []monv1.RemoteWriteSpec{{URL: "http://custom"}}
 
 				return c
 			},
@@ -864,10 +863,10 @@ func TestPrometheusK8sRemoteWrite(t *testing.T) {
 				}
 
 				c.SetRemoteWrite(true)
-				c.TelemeterClientConfig.TelemeterServerURL = "http://custom-telemeter"
-				c.TelemeterClientConfig.ClusterID = "123"
-				c.TelemeterClientConfig.Token = "secret"
-				c.PrometheusK8sConfig.RemoteWrite = []monv1.RemoteWriteSpec{{URL: "http://custom-remote-write"}}
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.TelemeterServerURL = "http://custom-telemeter"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.ClusterID = "123"
+				c.ClusterMonitoringConfiguration.TelemeterClientConfig.Token = "secret"
+				c.ClusterMonitoringConfiguration.PrometheusK8sConfig.RemoteWrite = []monv1.RemoteWriteSpec{{URL: "http://custom-remote-write"}}
 
 				return c
 			},
@@ -881,7 +880,7 @@ func TestPrometheusK8sRemoteWrite(t *testing.T) {
 		t.Run(tc.name, func(t *testing.T) {
 			c := tc.config()
 
-			f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+			f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 			p, err := f.PrometheusK8s(
 				"prometheus-k8s.openshift-monitoring.svc",
 				&v1.Secret{ObjectMeta: metav1.ObjectMeta{Name: "foo"}},
@@ -942,7 +941,7 @@ ingress:
 		"prom-label-proxy": "docker.io/openshift/origin-prom-label-proxy:latest",
 	})
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 	p, err := f.PrometheusK8s(
 		"prometheus-k8s.openshift-monitoring.svc",
 		&v1.Secret{ObjectMeta: metav1.ObjectMeta{Name: "foo"}},
@@ -960,16 +959,18 @@ ingress:
 		t.Fatal("Prometheus image is not configured correctly")
 	}
 
-	if p.Spec.Containers[K8S_CONTAINER_OAUTH_PROXY].Image != "docker.io/openshift/origin-oauth-proxy:latest" {
-		t.Fatal("oauth-proxy image is not configured correctly")
-	}
+	for _, container := range p.Spec.Containers {
+		if container.Name == "oauth-proxy" && container.Image != "docker.io/openshift/origin-oauth-proxy:latest" {
+			t.Fatalf("image for %s is not configured correctly: %s", container.Name, container.Image)
+		}
 
-	if p.Spec.Containers[K8S_CONTAINER_KUBE_RBAC_PROXY].Image != "docker.io/openshift/origin-kube-rbac-proxy:latest" {
-		t.Fatal("kube-rbac-proxy image is not configured correctly")
-	}
+		if container.Name == "kube-rbac-proxy" && container.Image != "docker.io/openshift/origin-kube-rbac-proxy:latest" {
+			t.Fatalf("image for %s is not configured correctly: %s", container.Name, container.Image)
+		}
 
-	if p.Spec.Containers[K8S_CONTAINER_PROM_LABEL_PROXY].Image != "docker.io/openshift/origin-prom-label-proxy:latest" {
-		t.Fatal("prom-label-proxy image is not configured correctly")
+		if container.Name == "prom-label-proxy" && container.Image != "docker.io/openshift/origin-prom-label-proxy:latest" {
+			t.Fatalf("image for %s is not configured correctly: %s", container.Name, container.Image)
+		}
 	}
 
 	cpuLimit := p.Spec.Resources.Limits[v1.ResourceCPU]
@@ -1031,7 +1032,7 @@ k8sPrometheusAdapter:
 		"k8s-prometheus-adapter": "docker.io/openshift/origin-k8s-prometheus-adapter:latest",
 	})
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 	d, err := f.PrometheusAdapterDeployment("foo", map[string]string{
 		"requestheader-allowed-names":        "",
 		"requestheader-extra-headers-prefix": "",
@@ -1081,7 +1082,7 @@ ingress:
 		"alertmanager": "docker.io/openshift/origin-prometheus-alertmanager:latest",
 	})
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 	a, err := f.AlertmanagerMain("alertmanager-main.openshift-monitoring.svc", nil)
 	if err != nil {
 		t.Fatal(err)
@@ -1140,7 +1141,7 @@ func TestNodeExporter(t *testing.T) {
 		"kube-rbac-proxy": "docker.io/openshift/origin-kube-rbac-proxy:latest",
 	})
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	ds, err := f.NodeExporterDaemonSet()
 	if err != nil {
@@ -1164,7 +1165,7 @@ func TestKubeStateMetrics(t *testing.T) {
 		"kube-rbac-proxy":    "docker.io/openshift/origin-kube-rbac-proxy:latest",
 	})
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	d, err := f.KubeStateMetricsDeployment()
 	if err != nil {
@@ -1195,7 +1196,7 @@ func TestOpenShiftStateMetrics(t *testing.T) {
 		"kube-rbac-proxy":         "docker.io/openshift/origin-kube-rbac-proxy:latest",
 	})
 
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	d, err := f.OpenShiftStateMetricsDeployment()
 	if err != nil {
@@ -1248,7 +1249,7 @@ func TestPrometheusK8sControlPlaneRulesFiltered(t *testing.T) {
 	}
 
 	for _, tc := range tests {
-		f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", tc.config)
+		f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", tc.config, NewAssets(assetsPath))
 		r, err := f.PrometheusK8sRules()
 		if err != nil {
 			t.Fatal(err)
@@ -1273,8 +1274,8 @@ func TestPrometheusK8sControlPlaneRulesFiltered(t *testing.T) {
 func TestPrometheusEtcdRulesFiltered(t *testing.T) {
 	enabled := false
 	c := NewDefaultConfig()
-	c.EtcdConfig.Enabled = &enabled
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	c.ClusterMonitoringConfiguration.EtcdConfig.Enabled = &enabled
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	r, err := f.PrometheusK8sRules()
 	if err != nil {
@@ -1291,8 +1292,8 @@ func TestPrometheusEtcdRulesFiltered(t *testing.T) {
 func TestPrometheusEtcdRules(t *testing.T) {
 	enabled := true
 	c := NewDefaultConfig()
-	c.EtcdConfig.Enabled = &enabled
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	c.ClusterMonitoringConfiguration.EtcdConfig.Enabled = &enabled
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	r, err := f.PrometheusK8sRules()
 	if err != nil {
@@ -1313,8 +1314,8 @@ func TestPrometheusEtcdRules(t *testing.T) {
 func TestEtcdGrafanaDashboardFiltered(t *testing.T) {
 	enabled := false
 	c := NewDefaultConfig()
-	c.EtcdConfig.Enabled = &enabled
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	c.ClusterMonitoringConfiguration.EtcdConfig.Enabled = &enabled
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	cms, err := f.GrafanaDashboardDefinitions()
 	if err != nil {
@@ -1331,8 +1332,8 @@ func TestEtcdGrafanaDashboardFiltered(t *testing.T) {
 func TestEtcdGrafanaDashboard(t *testing.T) {
 	enabled := true
 	c := NewDefaultConfig()
-	c.EtcdConfig.Enabled = &enabled
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	c.ClusterMonitoringConfiguration.EtcdConfig.Enabled = &enabled
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 
 	cms, err := f.GrafanaDashboardDefinitions()
 	if err != nil {
@@ -1371,7 +1372,7 @@ func TestThanosQuerierConfiguration(t *testing.T) {
 	}
 
 	tls := &v1.Secret{ObjectMeta: metav1.ObjectMeta{Name: "foo"}}
-	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c)
+	f := NewFactory("openshift-monitoring", "openshift-user-workload-monitoring", c, NewAssets(assetsPath))
 	d, err := f.ThanosQuerierDeployment(tls, false, nil)
 	if err != nil {
 		t.Fatal(err)
